@@ -166,6 +166,10 @@ class LdapAuth(AuthABC):
                 )
 
             if not ldapBases:
+                logger.debug(
+                    "User=%s, LDAP OU and/or CN search paths must be set.",
+                    userName,
+                )
                 raise LoginFailed(
                     "LDAPAuth: LDAP OU and/or CN search paths must be set."
                 )
@@ -173,6 +177,9 @@ class LdapAuth(AuthABC):
             userDetails = None
             for ldapBase in ldapBases:
                 ldapBase = "%s,%s" % (ldapBase, dcParts)
+                logger.debug(
+                    "User=%s, Searching in LDAP Base: %s", userName, ldapBase
+                )
 
                 try:
                     # Example Base : 'CN=atuser1,CN=Users,DC=synad,DC=synerty,DC=com'
@@ -183,21 +190,46 @@ class LdapAuth(AuthABC):
                     if userDetails:
                         break
 
+                    logger.debug(
+                        "User=%s, Checking next, user was not found in: %s",
+                        userName,
+                        ldapBase,
+                    )
+
                 except ldap.NO_SUCH_OBJECT:
-                    logger.warning("CN or OU doesn't exist : %s", ldapBase)
+                    logger.warning(
+                        "User=%s, CN or OU doesn't exist : %s",
+                        userName,
+                        ldapBase,
+                    )
 
         except ldap.NO_SUCH_OBJECT:
+            logger.info(
+                "User=%s, was not found in any LDAP bases, NO_SUCH_OBJECT",
+                userName,
+            )
             raise LoginFailed(
-                "LDAPAuth: An internal error occurred, ask admin to check "
-                "Attune logs"
+                "LDAPAuth: A user with username %s was not found, ask admin to "
+                "check Attune logs",
+                userName,
             )
 
         except ldap.INVALID_CREDENTIALS:
-            raise LoginFailed("LDAPAuth: Username or password is incorrect")
+            logger.info(
+                "User=%s, provided an incorrect userName or password, INVALID_CREDENTIALS"
+            )
+            raise LoginFailed(
+                "LDAPAuth: username or password is incorrect for %s", userName
+            )
 
         if not userDetails:
+            logger.info(
+                "User=%s, was not found in any LDAP bases, 'not userDetails'",
+                userName,
+            )
             raise LoginFailed(
-                "LDAPAuth: User doesn't belong to the correct CN/OUs"
+                "LDAPAuth: User %s doesn't belong to the correct CN/OUs",
+                userName,
             )
 
         userDetails = userDetails[0][1]
@@ -215,6 +247,11 @@ class LdapAuth(AuthABC):
         )
 
         ldapFilter = "(objectSid=%s)" % primaryGroupSid
+        logger.debug(
+            "User=%s, Primary group details LDAP filter: %s",
+            userName,
+            ldapFilter,
+        )
         primGroupDetails = conn.search_st(
             dcParts, ldap.SCOPE_SUBTREE, ldapFilter, None, 0, 10
         )
@@ -227,6 +264,12 @@ class LdapAuth(AuthABC):
             "(&(objectCategory=group)(member:1.2.840.113556.1.4.1941:=%s))"
             % (LdapAuth._escapeParensForLdapFilter(distinguishedName),)
         )
+        logger.debug(
+            "User=%s, Using recursive groups filter: %s", userName, ldapFilter
+        )
+        logger.info(
+            "Fetching groups from the LDAP server for user %s", userName
+        )
         groupDetails = conn.search_st(
             ",".join(distinguishedName.split(",")[1:]),
             ldap.SCOPE_SUBTREE,
@@ -248,6 +291,8 @@ class LdapAuth(AuthABC):
                 group = group.split("=")[1]
             groups.append(group)
 
+        logger.debug("User %s, is a member of groups: %s", userName, groups)
+
         userTitle = None
         if userDetails["displayName"]:
             userTitle = userDetails["displayName"][0].decode()
@@ -264,8 +309,25 @@ class LdapAuth(AuthABC):
                 [s.strip() for s in ldapSetting.ldapGroups.split(",")]
             )
 
-            if not ldapGroups & set(groups):
-                raise LoginFailed("User is not a member of an authorised group")
+        logger.debug(
+            "User=%s, Checking if user is a member of groups: %s",
+            userName,
+            groups,
+        )
+
+        if not ldapGroups & set(groups):
+            logger.info(
+                "User=%s, is not a member of any authorised group, 'not ldapGroups & set(groups)'",
+                userName,
+            )
+            raise LoginFailed(
+                "User %s is not a member of an authorised group", userName
+            )
+
+        logger.debug(
+            "User=%s, is a member of specified groups. Proceeding with login",
+            userName,
+        )
 
         newInternalUser = self._maybeCreateInternalUserBlocking(
             dbSession,
